@@ -52,7 +52,7 @@ from .base import (
     TempDirMixin,
 )
 from .transforms import Transform
-from .elements import LinearGradient, RadialGradient
+from .elements import LinearGradient, RadialGradient, MeshGradient
 from .command import write_svg, inkscape, ProgramRunError
 from .utils import errormsg
 from .localization import inkex_gettext as _
@@ -451,8 +451,10 @@ class ColorExtension(EffectExtension):
                 rgba_result = self._modify_color(name, col)
                 elem.style.set_color(rgba_result, name)
 
-            if isinstance(value, (LinearGradient, RadialGradient, Pattern)):
-                gradients.track(value, elem, self._ref_cloned, style=style, name=name)
+            if isinstance(
+                value, (LinearGradient, RadialGradient, MeshGradient, Pattern)
+            ):
+                gradients.track(value, elem, self._ref_cloned, element=elem, name=name)
                 if value.href is not None:
                     gradients.track(value.href, elem, self._xlink_cloned, linker=value)
         # Then opacities (usually does nothing)
@@ -464,9 +466,9 @@ class ColorExtension(EffectExtension):
             if result not in (value, 1):  # only modify if not equal to old or default
                 elem.style[name] = result
 
-    def _ref_cloned(self, old_id, new_id, style, name):
+    def _ref_cloned(self, old_id, new_id, element, name):
         self._renamed[old_id] = new_id
-        style[name] = f"url(#{new_id})"
+        element.style[name] = f"url(#{new_id})"
 
     def _xlink_cloned(self, old_id, new_id, linker):  # pylint: disable=unused-argument
         lid = linker.get("id")
@@ -483,9 +485,7 @@ class ColorExtension(EffectExtension):
         """Replace this method with your colour modifier method"""
         raise NotImplementedError("Provide a modify_color method.")
 
-    def modify_opacity(
-        self, name, opacity
-    ):  # pylint: disable=no-self-use, unused-argument
+    def modify_opacity(self, name, opacity):  # pylint: disable=no-self-use, unused-argument
         """Optional opacity modification"""
         return opacity
 
